@@ -21,7 +21,7 @@ SPEEDING = False
 DISCIPLINED = False
 REQUEST_LIMIT_TIME = 3600
 REQUEST_LIMIT_TRY = float('inf')
-REQUEST_LMIT_ITEM = float('inf')
+REQUEST_LIMIT_ITEM = float('inf')
 
 
 # Download progress bar divisor
@@ -44,6 +44,19 @@ EXCEPTIONAL_DATETIME_REPLACER = {
 }
 
 
+# 예외적인 코드의 예외적인 체결시간 케이스 변환기
+EXCEPTIONAL_DATETIME_REPLACER_FOR_EXCEPTIONAL_CODE = {
+    '253': {  # K200 F 매수 콜매도
+        '888888$': '170000',
+        '999999$': '180000',
+    },
+    '254': {  # K200 F 매도 풋매도
+        '888888$': '170000',
+        '999999$': '180000',
+    }
+}
+
+
 # 장 종료시간이 변경된 예외
 EXCEPTIONAL_DATES = {
     # 'YYYYMMDD': delay(hour)
@@ -75,7 +88,7 @@ def is_date(date):
 def is_market(code):
     code = str(code)
     if code not in MARKETS:
-        print(f'Market code must be one of {MARKETS}')
+        # print(f'Market code must be one of {MARKETS}')
         return False
     return True
 
@@ -83,14 +96,16 @@ def is_market(code):
 def is_market_gubun(code):
     code = str(code)
     if code not in MARKET_GUBUNS:
-        raise ValueError(f'Market Gubun code must be one of {MARKET_GUBUNS}')
+        # raise ValueError(f'Market Gubun code must be one of {MARKET_GUBUNS}')
+        return False
     return True
 
 
 def is_sector(code):
     code = str(code)
     if code not in SECTORS:
-        raise ValueError(f'Sector code must be one of {SECTOR}')
+        # raise ValueError(f'Sector code must be one of {SECTOR}')
+        return False
     return True
 
 
@@ -153,10 +168,10 @@ def boost():
     SPEEDING = True
     DISCIPLINED = False
 
-    global REQUEST_LIMIT_TIME, REQUEST_LIMIT_TRY, REQUEST_LMIT_ITEM
+    global REQUEST_LIMIT_TIME, REQUEST_LIMIT_TRY, REQUEST_LIMIT_ITEM
     REQUEST_LIMIT_TIME = 500
     REQUEST_LIMIT_TRY = 1000
-    REQUEST_LMIT_ITEM = 99
+    REQUEST_LIMIT_ITEM = 99
 
 
 def regret():
@@ -164,10 +179,10 @@ def regret():
     SPEEDING = False
     DISCIPLINED = True
 
-    global REQUEST_LIMIT_TIME, REQUEST_LIMIT_TRY, REQUEST_LMIT_ITEM
+    global REQUEST_LIMIT_TIME, REQUEST_LIMIT_TRY, REQUEST_LIMIT_ITEM
     REQUEST_LIMIT_TIME = 3600
     REQUEST_LIMIT_TRY = float('inf')
-    REQUEST_LMIT_ITEM = float('inf')
+    REQUEST_LIMIT_ITEM = float('inf')
 
 
 def preper(tr_code, otype):
@@ -302,31 +317,28 @@ _PERIOD_TO_DATETIME_FORMAT = {
 Configuration for pre-process
 """
 # How to pre-process for each output
-_PREP_FOR_OUTPUTS = {
+__PREP_FOR_OUTPUTS = {
     number: [
-        '평가손익', '총평가손익금액', '수익률(%)', '총수익률(%)',
-        '주문가격', '주문번호', '주문수량',
-        '예수금',  '보유수량',
+        '평가손익', '총평가손익금액', '수익률(%)',
+        '총수익률(%)', '주문가격', '주문번호',
+        '주문수량', '예수금',  '보유수량',
         '매입가', '전일종가', '미체결수량',
-        '체결량', '거래량',
-        '거래대금'
+        '체결량', '거래량', '거래대금'
     ],
     string: [
-        '종목번호', '종목코드', '종목명',
-        '주문상태', '일자', '체결시간',
-        '주문구분'
+        '종목번호', '종목코드', '업종코드',
+        '종목명', '주문상태', '일자',
+        '체결시간', '주문구분'
     ],
     remove_sign: [
-        '현재가', '시가', '고가',
-        '저가',
-
+        '현재가', '시가', '고가', '저가'
     ]
 }
 
 # Revert dictionary to be in the form of {'key': function}
 _PREP_FOR_OUTPUTS = defaultdict(
     lambda: string,
-    {val: key for key, vals in _PREP_FOR_OUTPUTS.items() for val in vals}
+    {val: key for key, vals in __PREP_FOR_OUTPUTS.items() for val in vals}
 )
 
 
@@ -414,135 +426,91 @@ _OUTPUTS_FOR_TR_CODE = {
     'opt10079': [  # 주식틱차트조회요청
         ['종목코드', '마지막틱갯수'],
         [
-            '체결시간', '현재가', '시가',
-            '고가', '저가', '거래량'
+            '체결시간', '현재가', '거래량'
         ]
     ],
     'opt10080': [  # 주식분봉차트조회요청
         ['종목코드'],
         [
-            '체결시간', '현재가', '시가',
-            '고가', '저가', '거래량'
+            '체결시간', '시가', '고가',
+            '저가', '현재가', '거래량'
         ]
     ],
     'opt10081': [  # 주식일봉차트조회요청
         ['종목코드'],
         [
-            '일자', '현재가', '시가',
-            '고가', '저가', '거래량',
+            '일자', '시가', '고가',
+            '저가', '현재가', '거래량',
             '거래대금'
         ]
     ],
     'opt10082': [  # 주식주봉차트조회요청
         ['종목코드'],
         [
-            '일자', '현재가', '시가',
-            '고가', '저가', '거래량',
+            '일자', '시가', '고가',
+            '저가', '현재가', '거래량',
             '거래대금'
         ]
     ],
     'opt10083': [  # 주식월봉차트조회요청
         ['종목코드'],
         [
-            '일자', '현재가', '시가',
-            '고가', '저가', '거래량',
+            '일자', '시가', '고가',
+            '저가', '현재가', '거래량',
             '거래대금'
         ]
     ],
     'opt10094': [  # 주식년봉차트조회요청
         ['종목코드'],
         [
-            '일자', '현재가', '시가',
-            '고가', '저가', '거래량',
-            '고가', '저가', '거래량',
+            '일자', '시가', '고가',
+            '저가', '현재가', '거래량',
             '거래대금'
         ]
     ],
-    'opt20001': [  # 업종현재가요청
-        [
-            '현재가', '시가', '고가',
-            '저가', '거래량', '거래대금',
-            '등락률', '전일대비', '거래형성종목수',
-            '거래형성비율',
-        ],
-        [
-            '시간n', '현재가n', '거래량n',
-            '누적거래량n', '등락률n', '전일대비n'
-        ]
-    ],
-    'opt20002': [  # 업종별주가요청
-        [],
-        [
-            '종목코드', '종목명', '현재가',
-            '시가', '고가', '저가',
-            '현재거래량', '등락률', '전일대비'
-        ]
-    ],
-    'opt20003': [  # 전업종지수요청
-        [],
-        [
-            '종목코드', '종목명', '현재가',
-            '전일대비', '등락률', '거래량',
-            '비중', '거래대금', '상장종목수'
-        ]
-    ],
     'opt20004': [  # 업종틱차트조회요청
         ['업종코드'],
         [
-            '체결시간', '현재가', '시가',
-            '고가', '저가', '거래량'
+            '체결시간', '현재가', '거래량'
         ]
     ],
     'opt20005': [  # 업종분봉조회요청
         ['업종코드'],
         [
-            '체결시간', '현재가', '시가',
-            '고가', '저가', '거래량'
+            '체결시간', '시가', '고가',
+            '저가', '현재가', '거래량'
         ]
     ],
     'opt20006': [  # 업종일봉조회요청
         ['업종코드'],
         [
-            '일자', '현재가', '시가',
-            '고가', '저가', '거래량',
+            '일자', '시가', '고가',
+            '저가', '현재가', '거래량',
             '거래대금'
         ]
     ],
     'opt20007': [  # 업종주봉조회요청
         ['업종코드'],
         [
-            '일자', '현재가', '시가',
-            '고가', '저가', '거래량',
+            '일자', '시가', '고가',
+            '저가', '현재가', '거래량',
             '거래대금'
         ]
     ],
     'opt20008': [  # 업종월봉조회요청
         ['업종코드'],
         [
-            '일자', '현재가', '시가',
-            '고가', '저가', '거래량',
+            '일자', '시가', '고가',
+            '저가', '현재가', '거래량',
             '거래대금'
         ]
     ],
-    'opt20009': [  # 업종현재가일별요청
-        [
-            '현재가', '전일대비', '등락률',
-            '거래량', '거래대금', '거래형성종목수',
-            '거래형성비율', '시가', '고가',
-            '저가'
-        ],
-        [
-            '일자n', '현재가n', '전일대비n',
-            '등락률n', '등락률n', '누적거래량n'
-        ]
-    ],
     'opt20019': [  # 업종년봉조회요청
         ['업종코드'],
         [
-            '현재가', '거래량', '일자',
-            '시가', '고가', '저가',
-            '거래대금', '대업종구분', '소업종구분',
-            '종목정보', '전일종가'
+            '일자', '시가', '고가',
+            '저가', '현재가', '거래량',
+            '거래대금'
         ]
     ],
 }
